@@ -5,15 +5,14 @@
 #' presence or absence of a collective anomaly across the components. It uses Circular Binary Segmentation to detect multiple collective anomalies.
 #' 
 #' 
-#' @param x An n x p real matrix representing n observations of p variates. The time series data classes ts, xts, and zoo are also supported.
+#' @param x A numeric matrix with n rows and p columns containing the data which is to be inspected. The time series data classes ts, xts, and zoo are also supported.
 #' @param alpha A positive integer > 0. This value is used to stabilise the higher criticism based test statistic used by PASS leading to a better finite sample familywise error rate. 
-#' Anomalies affecting fewer than alpha components will however in all likelihood escape detection.
+#' Anomalies affecting fewer than alpha components will however in all likelihood escape detection. The default is 2.
 #' @param lambda A positive real value setting the threshold value for the familywise Type 1 error. The default value
 #' is \eqn{(1.1 {\rm log}(n \times max\_seg\_len) +2 {\rm log}({\rm log}(p))) / \sqrt{{\rm log}({\rm log}(p))}}. 
 #' @param max_seg_len A positive integer (\code{max_seg_len} > 0) corresponding to the maximum segment length. This parameter corresponds to Lmax in Jeng et al. (2012). The default value is 10. 
 #' @param min_seg_len A positive integer (\code{max_seg_len} >= \code{min_seg_len} > 0) corresponding to the minimum segment length. This parameter corresponds to Lmin in Jeng et al. (2012).
 #' The default value is 1. 
-#' @param transform A function used to transform the data prior to analysis. The default value is to scale the data using the median and the median absolute deviation.
 #'
 #' @return An instance of an S4 object of type \code{.pass.class} containing the data \code{X}, procedure parameter values, and the results.
 #' 
@@ -22,20 +21,18 @@
 #' @examples
 #' library(anomaly)
 #' # generate some multivariate data
-#' set.seed(0)
-#' sim.data<-simulate(n=500,p=100,mu=2,locations=c(100,200,300),
-#'                    duration=6,proportions=c(0.04,0.06,0.08))
+#' data(simulated)
 #' res<-pass(sim.data)
 #' summary(res)
 #' plot(res,variate_names=TRUE)
 #'
 #' @export
 
-pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robustscale)
+pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1)
 {
     # reflect renamed variable
-    Lmax = max_seg_len
-    Lmin = min_seg_len
+    Lmax <- max_seg_len
+    Lmin <- min_seg_len
     # check the data
     x<-to_array(x)
     if(!is_array(x))
@@ -58,12 +55,7 @@ pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robu
     {
       stop("x contains Inf values")
     }
-    if(!is_function(transform))
-    {
-      stop("transform must be a function")
-    }
-    # transform data
-    Xi<-transform(x)
+    Xi<-x
     # check dimensions,types and values
     if(!check.alpha(Lmax))
     {
@@ -83,7 +75,7 @@ pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robu
     }
     ## LB ADDED - if number of variates < default alpha (2) -> alpha = 1
     if(dim(x)[2] < alpha){
-      alpha = 1
+      alpha <- 1
     }
     if(is.null(lambda))
     {
@@ -91,7 +83,7 @@ pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robu
       n_cols<-dim(x)[2]
       if (n_cols < 3){
         lambda <- 10
-        message = paste("The data has only N =", n_cols, "variates.", "Since the value of",  "\U03BB", "is based on asymptotic theory as the number of variates, N tends to infinity we suggest using simulations to determine a data-driven threshold to control the number of overselections. A default value of", "\U03BB = 10 has been used here.")
+        message <- paste("The data has only N =", n_cols, "variates.", "Since the value of",  "\U03BB", "is based on asymptotic theory as the number of variates, N tends to infinity we suggest using simulations to determine a data-driven threshold to control the number of overselections. A default value of", "\U03BB = 10 has been used here.")
         warning(message)
       }
       else{
@@ -149,16 +141,16 @@ pass<-function(x,alpha=2,lambda=NULL,max_seg_len=10,min_seg_len=1,transform=robu
 }
 
 
-check.alpha = function(input){
+check.alpha <- function(input){
   
-  res = (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0) && (!is.infinite(input)) && (input%%1 == 0)
+  res <- (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0) && (!is.infinite(input)) && (input%%1 == 0)
   return(res)
   
 }
 
-check.lambda = function(input){
+check.lambda <- function(input){
   
-  res = (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0)
+  res <- (length(input) == 1) && (is.numeric(input)) && (!is.nan(input)) && (input > 0)
   return(res)
   
 }
\ No newline at end of file
