@@ -1,5 +1,5 @@
-#include <math.h>
-#include <stdlib.h>
+//#include <math.h>
+//#include <stdlib.h>
 #include <list>
 #include "tukey.h"
 
